@@ -1,9 +1,9 @@
 package Archive::Any::Zip;
-$Archive::Any::Zip::VERSION = '0.0944';
+$Archive::Any::Zip::VERSION = '0.0945';
 use strict;
 use warnings;
-require Archive::Any;
-@ISA = qw(Archive::Any);
+
+use base 'Archive::Any';
 
 use Archive::Zip qw(:ERROR_CODES);
 use Cwd;
@@ -67,7 +67,7 @@ Archive::Any::Zip - Archive::Any wrapper around Archive::Zip
 
 =head1 VERSION
 
-version 0.0944
+version 0.0945
 
 =head1 SYNOPSIS
 
